-- openURL.lua (version 1.0, 12/14/2018)
-- Mark Sullivan sullivm@geneseo.edu
-- Original Script written by Kevin Reiss
-- 
-- Opens aleph Catalog for ISBN/ISSN/OCLC Number/Title String Search


-- define your Aleph Catalog Search string options
local settings = {};
settings.myBaseURL = GetSetting("AlephBaseURL");
settings.myLocalBase = "&local_base=" .. GetSetting("AlephLocalBase");
settings.myBranding = GetSetting("CatBrand");
settings.myIssnString = "func=find-b&find_code=022&request=";
settings.myIsbnString = "func=find-b&find_code=020&request=";
settings.myOCLCNumString  = "func=find-b&find_code=035&request=";
-- use FIND_WRD for all keywords, FIND_WTI for just Title keywords
settings.myTitleString = "func=find-e&find_scan_code=FIND_WTI&request=";
settings.UseOCLCNum = GetSetting("UseOCLCNum");


-- set scriptActive to true for this script to run, false to stop it from running.
settings.scriptActive = GetSetting("Active");

local AlephSearchForm = {};
AlephSearchForm.Form = nil;
AlephSearchForm.Browser = nil;
AlephSearchForm.RibbonPage = nil;

require "Atlas.AtlasHelpers";

function Init()
	if settings.scriptActive then
		interfaceMngr = GetInterfaceManager();
		
		AlephSearchForm.Form = interfaceMngr:CreateForm(settings.myBranding, "Script");
	
		-- Add a browser
		AlephSearchForm.Browser = AlephSearchForm.Form:CreateBrowser(settings.myBranding, "Aleph Browser", settings.myBranding);
	
		-- Hide the text label
		AlephSearchForm.Browser.TextVisible = false;
	
		-- Since we didn't create a ribbon explicitly before creating our browser, it will have created one using the name we passed the CreateBrowser method.  We can retrieve that one and add our buttons to it.
		AlephSearchForm.RibbonPage = AlephSearchForm.Form:GetRibbonPage(settings.myBranding);

		-- Create button
		AlephSearchForm.RibbonPage:CreateButton("Search", GetClientImage("Search32"), "Search", settings.myBranding);
		AlephSearchForm.RibbonPage:CreateButton("Title Search", GetClientImage("Search32"), "TitleSearch", settings.myBranding);

		AlephSearchForm.Form:Show();
		
		Search();
	end
end

function Search()

	  local myISxN = GetFieldValue("Transaction", "ISSN");
	  local myOCLCNum = GetFieldValue("Transaction", "ESPNumber");

    if myOCLCNum:len()>0 and UseOCLCNum then
        myURL = settings.myBaseURL .. "?" .. settings.myOCLCNumString .. myOCLCNum .. settings.myLocalBase;
    else

		if GetFieldValue("Transaction", "RequestType") == "Article" then
		--   build URL for articles
			
			local myTitle = GetFieldValue("Transaction", "PhotoJournalTitle");


			if myISxN:len()>0 then
				myURL = settings.myBaseURL .. "?" .. settings.myIssnString .. myISxN .. settings.myLocalBase;
			else
				myURL = settings.myBaseURL .. "?" .. settings.myTitleString .. myTitle .. settings.myLocalBase;
			end

		else
			-- build URL for books and other 'returnables'
	
			local myTitle = string.gsub(GetFieldValue("Transaction", "LoanTitle"),"/","");
      
			if myISxN:len()>0 then
				myURL = settings.myBaseURL .. "?" .. settings.myIsbnString .. myISxN .. settings.myLocalBase;
	   		else
	   			myURL = settings.myBaseURL .. "?" .. settings.myTitleString .. myTitle .. settings.myLocalBase;
		  	end
		end
	end
	
	AlephSearchForm.Browser:Navigate(myURL);
	
end

function TitleSearch()

	 if GetFieldValue("Transaction", "RequestType") == "Article" then
		--   build URL for articles
		local myTitle = string.gsub(GetFieldValue("Transaction", "PhotoJournalTitle"),"/","");
		myURL = settings.myBaseURL .. "?" .. settings.myTitleString .. myTitle .. settings.myLocalBase;
	else
		-- build URL for books and other 'returnables'
		local myTitle = string.gsub(GetFieldValue("Transaction", "LoanTitle"),"/","");
	   	myURL = settings.myBaseURL .. "?" .. settings.myTitleString .. myTitle .. settings.myLocalBase;
	end
	
	AlephSearchForm.Browser:Navigate(myURL);
	
end
